#[repr(u32)]pub enum AuthorityLookupError {
InvalidUrl = 1,
PinnedUrlNotAllowed = 2,
RepositoryNotFound = 3,
PackageNotFound = 4,
UpstreamConnection = 5,
Internal = 6,
}Variants
InvalidUrl = 1
package_url was not a valid package URL.
PinnedUrlNotAllowed = 2
package_url was pinned, which is not allowed.
RepositoryNotFound = 3
This Authority is not aware of the repository indicated by package_url.
PackageNotFound = 4
The repository indicated by package_url does not contain the indicated package.
UpstreamConnection = 5
This Authority failed to communicate with an upstream authority of its own, so this
Authority does not know if it has the package. Clients may attempt to fallback to a
different authority.
Internal = 6
There was an error with the configuration or operation of this Authority or its
dependencies.
Implementations
Sourceimpl AuthorityLookupError
impl AuthorityLookupError
pub fn from_primitive(prim: u32) -> Option<AuthorityLookupError>
pub const fn into_primitive(self) -> u32