pub struct AuthorityLookupResponse {
pub package_id: BlobId,
pub http_blob_dir: String,
}Fields
package_id: BlobIdThe id of the package (the hash of its meta.far).
http_blob_dir: StringA URL of a directory on an HTTP[S] server that contains all of the blobs of the package. The filenames of the blobs in the directory are the hex-encoded hashes of the blobs. The blob files are contained directly in the directory (e.g. the delivery blob type does not need to be appended to the URL).