pub struct AuthorityMarker;Trait Implementations
Sourceimpl Clone for AuthorityMarker
impl Clone for AuthorityMarker
Sourcefn clone(&self) -> AuthorityMarker
fn clone(&self) -> AuthorityMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AuthorityMarker
Sourceimpl Debug for AuthorityMarker
impl Debug for AuthorityMarker
Sourceimpl DiscoverableProtocolMarker for AuthorityMarker
impl DiscoverableProtocolMarker for AuthorityMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
impl Eq for AuthorityMarker
Sourceimpl Hash for AuthorityMarker
impl Hash for AuthorityMarker
Sourceimpl Ord for AuthorityMarker
impl Ord for AuthorityMarker
Sourcefn cmp(&self, other: &AuthorityMarker) -> Ordering
fn cmp(&self, other: &AuthorityMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for AuthorityMarker
impl PartialEq for AuthorityMarker
Sourceimpl PartialOrd for AuthorityMarker
impl PartialOrd for AuthorityMarker
Sourceimpl ProtocolMarker for AuthorityMarker
impl ProtocolMarker for AuthorityMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.pkg.Authority"
const DEBUG_NAME: &'static str = "fuchsia.pkg.Authority"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = AuthorityProxy
type Proxy = AuthorityProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = AuthorityRequestStream
type RequestStream = AuthorityRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = AuthoritySynchronousProxy
type SynchronousProxy = AuthoritySynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for AuthorityMarker