pub struct RepositoryManagerProxy { /* private fields */ }Implementations
Sourceimpl RepositoryManagerProxy
impl RepositoryManagerProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.pkg/RepositoryManager.
Sourcepub fn take_event_stream(&self) -> RepositoryManagerEventStream
pub fn take_event_stream(&self) -> RepositoryManagerEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn add(
&self,
repo: &RepositoryConfig,
) -> QueryResponseFut<RepositoryManagerAddResult, DefaultFuchsiaResourceDialect>
pub fn add( &self, repo: &RepositoryConfig, ) -> QueryResponseFut<RepositoryManagerAddResult, DefaultFuchsiaResourceDialect>
Adds a repository. This will overwrite the repository if it already exists.
- request
repoa repository to add to the resolver.
- error a zx_status value indicating failure. One of the following:
ZX_ERR_ACCESS_DENIEDif editing repositories is permanently disabled.ZX_ERR_ALREADY_EXISTSif the repository already exists.ZX_ERR_INVALID_ARGSif the repository is malformed.
Sourcepub fn remove(
&self,
repo_url: &str,
) -> QueryResponseFut<RepositoryManagerRemoveResult, DefaultFuchsiaResourceDialect>
pub fn remove( &self, repo_url: &str, ) -> QueryResponseFut<RepositoryManagerRemoveResult, DefaultFuchsiaResourceDialect>
Removes a repository.
Removing a repository will prevent future packages from being cached from this repository, but in-flight downloads may not be interrupted.
- request
repo_urlthe URL of the repository we want to remove.
- error a zx_status value indicating failure. One of the following:
ZX_ERR_ACCESS_DENIEDif editing repositories is permanently disabled or therepo_urlmatches a static repository.ZX_ERR_INVALID_ARGSif therepo_urlis malformed.ZX_ERR_NOT_FOUNDif the repository does not exist.
Sourcepub fn add_mirror(
&self,
repo_url: &str,
mirror: &MirrorConfig,
) -> QueryResponseFut<RepositoryManagerAddMirrorResult, DefaultFuchsiaResourceDialect>
pub fn add_mirror( &self, repo_url: &str, mirror: &MirrorConfig, ) -> QueryResponseFut<RepositoryManagerAddMirrorResult, DefaultFuchsiaResourceDialect>
Adds a mirror to a repository. This will overwrite the mirror if it already exists.
- request
repo_urlthe URL of the repository to add the mirror to. - request
mirrorthe mirror config used to add the mirror.
- error a zx_status value indicating failure. One of the following:
ZX_ERR_ALREADY_EXISTSif the mirror for this repository already exists.ZX_ERR_INVALID_ARGSif therepo_urlor themirroris malformed.ZX_ERR_NOT_FOUNDif the repository does not exist.
Sourcepub fn remove_mirror(
&self,
repo_url: &str,
mirror_url: &str,
) -> QueryResponseFut<RepositoryManagerRemoveMirrorResult, DefaultFuchsiaResourceDialect>
pub fn remove_mirror( &self, repo_url: &str, mirror_url: &str, ) -> QueryResponseFut<RepositoryManagerRemoveMirrorResult, DefaultFuchsiaResourceDialect>
Removes a mirror from a repository.
Removing a mirror will prevent future packages from being cached from that mirror, but in-flight downloads may not be interrupted.
- request
repo_urlthe URL of the mirror’s repository. - request
mirror_urlthe URL of the mirror we want to remove.
- error a zx_status value indicating failure. One of the following:
ZX_ERR_INVALID_ARGSif therepo_urlor themirror_urlis malformed.ZX_ERR_NOT_FOUNDif the repository or mirror does not exist.